import 'package:flutter/widgets.dart';
import 'package:info_tren/models/ui_design.dart';
import 'package:info_tren/pages/station_arrdep_page/select_station/select_station_cupertino.dart';
import 'package:info_tren/pages/station_arrdep_page/select_station/select_station_material.dart';
import 'package:info_tren/pages/station_arrdep_page/view_station/view_station.dart';
import 'package:info_tren/utils/default_ui_design.dart';
import 'package:info_tren/api/stations.dart' as apiStations;

class SelectStationPage extends StatefulWidget {
  final UiDesign? uiDesign;

  const SelectStationPage({ Key? key, this.uiDesign }) : super(key: key);

  static String routeName = '/stationArrDep/selectStation';

  @override
  SelectStationPageState createState() {
    final uiDesign = this.uiDesign ?? defaultUiDesign;
    switch (uiDesign) {
      case UiDesign.MATERIAL:
        return SelectStationPageStateMaterial();
      case UiDesign.CUPERTINO:
        return SelectStationPageStateCupertino();
    }
  }
}

abstract class SelectStationPageState extends State<SelectStationPage> {
  static const pageTitle = 'Plecări/sosiri stație';
  static const textFieldLabel = 'Numele stației';
  static const roToEn = {
    'ă': 'a',
    'â': 'a',
    'î': 'i',
    'ș': 's',
    'ț': 't',
  };
  List<String> stations = [];

  List<String> get filteredStations {
    final filter = textEditingController.text
      .trim()
      .toLowerCase()
      .replaceAllMapped(RegExp(r'[ăâîșț]'), (match) => roToEn[match[0]!]!);
    if (filter.isEmpty) {
      return stations;
    }
    
    return stations.where(
      (e) => e
        .toLowerCase()
        .replaceAllMapped(RegExp(r'[ăâîșț]'), (match) { 
          return roToEn[match[0]!]!;
        })
        .contains(filter)
    ).toList(growable: false);
  }

  @override
  void initState() {
    apiStations.stations.then((value) {
      setState(() {
        stations = value.map((e) => e.name).toList(growable: false,);
      });
    });

    super.initState();
  }

  void onTextChanged(String newText) {
    setState(() {});
  }

  void onSuggestionSelected(String suggestion) {
    Navigator.of(context).pushNamed(ViewStationPage.routeName, arguments: suggestion);
  }

  final TextEditingController textEditingController = TextEditingController();

}
