import 'package:flutter/widgets.dart';
import 'package:info_tren/api/station_data.dart';
import 'package:info_tren/components/refresh_future_builder.dart';
import 'package:info_tren/models/station_data.dart';
import 'package:info_tren/models/ui_design.dart';
import 'package:info_tren/pages/station_arrdep_page/view_station/view_station_cupertino.dart';
import 'package:info_tren/pages/station_arrdep_page/view_station/view_station_material.dart';
import 'package:info_tren/pages/train_info_page/view_train/train_info.dart';
import 'package:info_tren/utils/default_ui_design.dart';

class ViewStationPage extends StatefulWidget {
  final UiDesign? uiDesign;
  final String stationName;
  
  const ViewStationPage({ Key? key, required this.stationName, this.uiDesign }) : super(key: key);

  static String routeName = '/stationArrDep/viewStation';

  @override
  ViewStationPageState createState() {
    final uiDesign = this.uiDesign ?? defaultUiDesign;
    switch (uiDesign) {
      case UiDesign.MATERIAL:
        return ViewStationPageStateMaterial();
      case UiDesign.CUPERTINO:
        return ViewStationPageStateCupertino();
    }
  }
}

abstract class ViewStationPageState extends State<ViewStationPage> {
  static const arrivals = 'Sosiri';
  static const departures = 'Pleacări';
  static const loadingText = 'Se încarcă...';
  static const arrivesFrom = 'Sosește de la';
  static const departsTo = 'Pleacă către';

  ViewStationPageTab tab = ViewStationPageTab.departures;
  late String stationName;
  late Future<StationData> Function() futureCreator;

  @override
  void initState() {
    initData();
    super.initState();
  }

  @override
  void didChangeDependencies() {
    if (stationName != widget.stationName) {
      setState(() {
        initData();
      });
    }
    super.didChangeDependencies();
  }

  void initData() {
    stationName = widget.stationName;
    futureCreator = () => getStationData(stationName);
  }

  Widget buildContent(BuildContext context, Future Function() refresh, RefreshFutureBuilderSnapshot<StationData> snapshot);
  Widget buildStationArrivalItem(BuildContext context, StationArrival item);
  Widget buildStationDepartureItem(BuildContext context, StationDeparture item);

  void onTabChange(int index) {
    setState(() {
      tab = ViewStationPageTab.values[index];
    });
  }

  void onTrainTapped(String trainNumber) {
    Navigator.of(context).pushNamed(TrainInfo.routeName, arguments: trainNumber);
  }

  @override
  Widget build(BuildContext context) {
    return RefreshFutureBuilder(
      futureCreator: futureCreator,
      builder: buildContent,
    );
  }
}

enum ViewStationPageTab {
  arrivals,
  departures,
}