import 'package:flutter/cupertino.dart';
import 'package:info_tren/components/loading/loading.dart';
import 'package:info_tren/components/refresh_future_builder.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:info_tren/components/sliver_persistent_header_padding.dart';
import 'package:info_tren/models/station_data.dart';
import 'package:info_tren/pages/station_arrdep_page/view_station/view_station.dart';

class ViewStationPageStateCupertino extends ViewStationPageState {
  @override
  Widget buildContent(BuildContext context, Future Function() refresh, RefreshFutureBuilderSnapshot<StationData> snapshot) {
    return CupertinoPageScaffold(
      navigationBar: CupertinoNavigationBar(
        middle: Text(snapshot.hasData ? snapshot.data!.stationName : stationName),
      ),
      child: snapshot.hasData ? CupertinoTabScaffold(
        tabBar: CupertinoTabBar(
          items: [
            BottomNavigationBarItem(
              icon: Icon(CupertinoIcons.arrow_down),
              label: ViewStationPageState.arrivals,
            ),
            BottomNavigationBarItem(
              icon: Icon(CupertinoIcons.arrow_up),
              label: ViewStationPageState.departures,
            ),
          ],
          onTap: onTabChange,
          currentIndex: tab.index,
        ),
        tabBuilder: (context, index) {
          final topPadding = MediaQuery.of(context).padding.top;
          return NestedScrollView(
            headerSliverBuilder: (context, _) {
              return [SliverPersistentHeaderPadding(maxHeight: topPadding)];
            },
            body: CustomScrollView(
              slivers: [
                SliverList(
                  delegate: SliverChildBuilderDelegate(
                    (context, index) {
                      return tab == ViewStationPageTab.arrivals ? buildStationArrivalItem(context, snapshot.data!.arrivals![index]) : buildStationDepartureItem(context, snapshot.data!.departures![index]);
                    },
                    childCount: tab == ViewStationPageTab.arrivals ? snapshot.data!.arrivals?.length ?? 0 : snapshot.data!.departures?.length ?? 0,
                  ),
                ),
              ],
            ),
          );
        },
      ) : snapshot.state == RefreshFutureBuilderState.waiting ? Loading(text: ViewStationPageState.loadingText, uiDesign: widget.uiDesign,) : Container(),
    );
  }

  @override
  Widget buildStationArrivalItem(BuildContext context, StationArrival item) {
    return GestureDetector(
      onTap: () => onTrainTapped(item.train.number),
      child: CupertinoFormRow(
        child: Text('${item.time.toLocal().hour.toString().padLeft(2, '0')}:${item.time.toLocal().minute.toString().padLeft(2, '0')}'),
        prefix: Text.rich(
          TextSpan(
            children: [
              TextSpan(
                text: item.train.rank,
                style: TextStyle(
                  color: item.train.rank.startsWith('IR') ? Color.fromARGB(255, 255, 0, 0) : null,
                ),
              ),
              TextSpan(text: ' '),
              TextSpan(text: item.train.number,),
            ],
          ),
        ),
        helper: Text.rich(
          TextSpan(
            children: [
              TextSpan(text: ViewStationPageState.arrivesFrom),
              TextSpan(text: ' '),
              TextSpan(text: item.train.origin),
            ],
          ),
        ),
      ),
    );
  }

  @override
  Widget buildStationDepartureItem(BuildContext context, StationDeparture item) {
    return GestureDetector(
      onTap: () => onTrainTapped(item.train.number),
      child: CupertinoFormRow(
        child: Text('${item.time.toLocal().hour.toString().padLeft(2, '0')}:${item.time.toLocal().minute.toString().padLeft(2, '0')}'),
        prefix: Text.rich(
          TextSpan(
            children: [
              TextSpan(
                text: item.train.rank,
                style: TextStyle(
                  color: item.train.rank.startsWith('IR') ? Color.fromARGB(255, 255, 0, 0) : null,
                ),
              ),
              TextSpan(text: ' '),
              TextSpan(text: item.train.number,),
            ],
          ),
        ),
        helper: Text.rich(
          TextSpan(
            children: [
              TextSpan(text: ViewStationPageState.departsTo),
              TextSpan(text: ' '),
              TextSpan(text: item.train.destination),
            ],
          ),
        ),
      ),
    );
  }
}