import 'package:flutter/material.dart';
import 'package:info_tren/components/loading/loading.dart';
import 'package:info_tren/components/refresh_future_builder.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:info_tren/models/station_data.dart';
import 'package:info_tren/pages/station_arrdep_page/view_station/view_station.dart';

class ViewStationPageStateMaterial extends ViewStationPageState {
  @override
  Widget buildContent(BuildContext context, Future Function() refresh, RefreshFutureBuilderSnapshot<StationData> snapshot) {
    return Scaffold(
      appBar: AppBar(
        title: Text(snapshot.hasData ? snapshot.data!.stationName : stationName),
        centerTitle: true,
      ),
      body: snapshot.state == RefreshFutureBuilderState.waiting ? Loading(text: ViewStationPageState.loadingText, uiDesign: widget.uiDesign,) : CustomScrollView(
        slivers: [
          SliverToBoxAdapter(child: SafeArea(child: Container(), left: false, bottom: false, right: false,),),
          SliverList(
            delegate: SliverChildBuilderDelegate(
              (context, index) {
                return tab == ViewStationPageTab.arrivals ? buildStationArrivalItem(context, snapshot.data!.arrivals![index]) : buildStationDepartureItem(context, snapshot.data!.departures![index]);
              },
              childCount: tab == ViewStationPageTab.arrivals ? snapshot.data!.arrivals?.length ?? 0 : snapshot.data!.departures?.length ?? 0,
            ),
          ),
        ],
      ),
      bottomNavigationBar: snapshot.hasData ? BottomNavigationBar(
        items: [
          BottomNavigationBarItem(
            icon: Icon(Icons.arrow_downward),
            label: ViewStationPageState.arrivals,
          ),
          BottomNavigationBarItem(
            icon: Icon(Icons.arrow_upward),
            label: ViewStationPageState.departures,
          ),
        ],
        currentIndex: tab.index,
        onTap: onTabChange,
      ) : null,
    );
  }

  @override
  Widget buildStationArrivalItem(BuildContext context, StationArrival item) {
    return ListTile(
      leading: Text('${item.time.toLocal().hour.toString().padLeft(2, '0')}:${item.time.toLocal().minute.toString().padLeft(2, '0')}'),
      title: Text.rich(
        TextSpan(
          children: [
            TextSpan(
              text: item.train.rank,
              style: TextStyle(
                color: item.train.rank.startsWith('IR') ? Color.fromARGB(255, 255, 0, 0) : null,
              ),
            ),
            TextSpan(text: ' '),
            TextSpan(text: item.train.number,),
          ],
        ),
      ),
      subtitle: Text.rich(
        TextSpan(
          children: [
            TextSpan(text: ViewStationPageState.arrivesFrom),
            TextSpan(text: ' '),
            TextSpan(text: item.train.origin),
          ],
        ),
      ),
      onTap: () => onTrainTapped(item.train.number),
    );
  }

  @override
  Widget buildStationDepartureItem(BuildContext context, StationDeparture item) {
    return ListTile(
      leading: Text('${item.time.toLocal().hour.toString().padLeft(2, '0')}:${item.time.toLocal().minute.toString().padLeft(2, '0')}'),
      title: Text.rich(
        TextSpan(
          children: [
            TextSpan(
              text: item.train.rank,
              style: TextStyle(
                color: item.train.rank.startsWith('IR') ? Color.fromARGB(255, 255, 0, 0) : null,
              ),
            ),
            TextSpan(text: ' '),
            TextSpan(text: item.train.number,),
          ],
        ),
      ),
      subtitle: Text.rich(
        TextSpan(
          children: [
            TextSpan(text: ViewStationPageState.departsTo),
            TextSpan(text: ' '),
            TextSpan(text: item.train.destination),
          ],
        ),
      ),
      onTap: () => onTrainTapped(item.train.number),
    );
  }
}